//
//  Exporter.h
//  Exporter
//
//  Created by Rui Pacheco on 14/12/2010.
//  Copyright 2010 Lost Bytes. All rights reserved.
//

#import <Cocoa/Cocoa.h>



/*!
 @abstract Types of files the exporter can write.
 */
typedef enum {
	ExporterCSV = 0,
	ExporterTSV = 1,
	ExporterHTML = 2,
    ExporterExcel = 3,
	ExporterXML = 4,
    ExporterOpenOffice = 5
} ExporterFileTypes;

/*!
 @abstract Export data into a type of file.
 
 @discussion This class receives data and exports it into the specified format.
 */
@interface Exporter : NSObject {
	
@private
	/*!
     @abstract Path in disk data is to be written to.
	 */
	NSMutableString *path;
	
	/*!
     @abstract Holds a reference to the data to be exported.
     *
     * @discussion This is meant to be a bidimensional array representing tabular data.
	 */
	NSArray *data;
	
	/*!
	 * @abstract Type of file data is to be written to.
	 */
	ExporterFileTypes fileType;
	
	/*!
	 * @abstract Holds contents of file.
	 *
	 * @discussion Each helper method assigns the result of it's work to this 
	 * variable that is then written to disk.
	 */
	NSMutableString *fileContent;
}

/*!
 * @abstract Initializes the exporter object.
 * 
 * @discussion Initializes the exporter object with the path the file is to be 
 * written to, the data to be written and the format to be written into.
 *
 * Expects someData to be a bidimensional array.
 */
- (id)initWithPath:(NSString *)aPath dataToSave:(NSArray *)someData fileType:(ExporterFileTypes)theType;

/*!
 * @abstract Initiates file export.
 *
 * @discussion Uses data passed to the constructor to do the actual file writing to
 * disk. Ideally this should be offloaded to a separate thread.
 */
- (BOOL)export:(NSError **)error;

@end
