//
//  SQLEditor.h
//  SQLEditor
//
//  Created by Rui Pacheco on 5/9/13.
//  Copyright (c) 2013 Rui Pacheco. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "SQLThemeManager.h"
#import "SQLTheme.h"


@class SQLScanner;

/*!
 @abstract SQL aware textview.
 
 @discussion This text view is aware of its content, meaning that it knows the position of every SQL statement, comment,
 string and unknown entity in the buffer.
 */
@interface SQLEditor : NSTextView <NSTextViewDelegate> {
    
    /*!
     @abstract Try to find meaning in what users give us.
     */
    @protected SQLScanner *scanner;

    /*!
     @abstract List of all PostgreSQL keywords, used for syntax highlight.
     */
    @protected NSMutableArray *keywords;
}

@property (readwrite) NSArray *databases;
@property (readwrite) NSArray *schemas;
@property (readwrite) NSArray *tables;
@property (readwrite) NSArray *columns;
@property (readwrite) NSArray *functions;
@property (readwrite) NSArray *triggers;
@property (readwrite) NSArray *views;

/*!
 @abstract Returns an NSTextView that understands PostgreSQL.
 
 @discussion Creates a PostgreSQL aware text view with the dimensions of aView and sets the text view as the subview of
 aView.
 */
+ (SQLEditor *)newEditorForPostgreSQLInView:(NSView *)aView;

/*!
 @abstract Returns an NSTextView that understands MariaDB.

 @discussion Creates a MariaDB aware text view with the dimensions of aView and sets the text view as the subview of
 aView.
 */
+ (SQLEditor *)newEditorForMariaDBInView:(NSView *)aView;

/*!
 @abstract Designated initializer.
 
 @discussion Don't use this, use the factories instead.
 */
- (id)initInView:(NSView *)aView;

/*!
 @abstract Returns an array of strings with all selected statements.
 */
- (NSArray *)statements;

/*!
 @abstract Returns content of files as arrays.
 
 @discussion Used by subclasses.
 */
- (NSArray *)readFile:(NSString *)fileName;

@end
