//
//  SQLThemeManager.h
//  SQLEditor
//
//  Created by Rui Pacheco on 5/13/13.
//  Copyright (c) 2013 Rui Pacheco. All rights reserved.
//

#import <Foundation/Foundation.h>



static NSString *const SelectedThemeIdentifier = @"SelectedThemeIdentifier";

@class SQLTheme;

/*!
 @abstract Manages all theme files, built-in and provided by the user.
 */
@interface SQLThemeManager : NSObject

+ (SQLThemeManager *)newManager;

/*!
 @abstract Returns an array with the names of all available themes.
 */
- (NSArray *)availableThemes;

/*!
 @abstract Sets the default theme.
 
 @discussion Checks if the name exists and if so sets that theme as the user selected theme. If it does not exist, the theme defaults to Mr.
 
 Returns true if the selected theme was set successfully.
 */
- (BOOL)selectTheme:(NSString *)aName;

/*!
 @abstract Returns the currently selected theme.
 */
- (SQLTheme *)selectedTheme;

/*!
 @abstract Path to the folder that holds custom themes.
 */
- (NSString *)themeFolderPath;

/*!
 @abstract Set path to folder that holds themes.
 */
- (void)setThemeFolderPath:(NSString *)themeFolderPath;

@end
